==> peony_4.20.2.1.orig.tar.gz: peony-4.20.2.1/stable/ukui3/properties-window/properties-window-factory.cpp <==
/*
 * Peony-Qt's Library
 *
 * Copyright (C) 2023, Tianjin KYLIN Information Technology Co., Ltd.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this library.  If not, see <https://www.gnu.org/licenses/>.
 *
 * Authors: Yue Lan <yangyanwei@kylinos.cn>
 *
 */

#include "properties-window-factory.h"
#include "properties-window.h"

using namespace Peony;

static StablePropertiesWindowFactory *global_instance = nullptr;

StablePropertiesWindowFactory::StablePropertiesWindowFactory(QObject *parent) : QObject(parent)
{
    PropertiesWindowPluginManager::getInstance()->initFactory();
}

StablePropertiesWindowFactory *StablePropertiesWindowFactory::getInstance()
{
    if (!global_instance)
        global_instance = new StablePropertiesWindowFactory;
    return global_instance;
}

QMainWindow *StablePropertiesWindowFactory::create(const QStringList &uris, QWidget *parent)
{
    m_window = new StablePropertiesWindow(uris, parent);
    return m_window;
}

void StablePropertiesWindowFactory::closeFactory()
{
    this->deleteLater();
}

bool StablePropertiesWindowFactory::registerFactory(QObject *factory)
{
    PropertiesWindowTabPagePluginIface *Iface = dynamic_cast<PropertiesWindowTabPagePluginIface*>(factory);
    return PropertiesWindowPluginManager::getInstance()->registerFactory(Iface);
}

bool StablePropertiesWindowFactory::unregisterFactory(QObject *factory)
{
    PropertiesWindowTabPagePluginIface *Iface = dynamic_cast<PropertiesWindowTabPagePluginIface*>(factory);
    return PropertiesWindowPluginManager::getInstance()->unregisterFactory(Iface);
}

void StablePropertiesWindowFactory::show()
{
    if (m_window) {
        m_window->show();
    }
}

==> peony_5.0.0.1.orig.tar.gz: peony-5.0.0.1/stable/ukui3/properties-window/properties-window-factory.cpp <==
/*
 * Peony-Qt's Library
 *
 * Copyright (C) 2023, Tianjin KYLIN Information Technology Co., Ltd.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this library.  If not, see <https://www.gnu.org/licenses/>.
 *
 * Authors: Yue Lan <yangyanwei@kylinos.cn>
 *
 */

#include "properties-window-factory.h"
#include "properties-window.h"

using namespace Peony;

static StablePropertiesWindowFactory *global_instance = nullptr;

StablePropertiesWindowFactory::StablePropertiesWindowFactory(QObject *parent) : QObject(parent)
{
    PropertiesWindowPluginManager::getInstance()->initFactory();
}

StablePropertiesWindowFactory *StablePropertiesWindowFactory::getInstance()
{
    if (!global_instance)
        global_instance = new StablePropertiesWindowFactory;
    return global_instance;
}

QMainWindow *StablePropertiesWindowFactory::create(const QStringList &uris)
{
    auto window = new StablePropertiesWindow(uris);
    return window;
}

void StablePropertiesWindowFactory::closeFactory()
{
    this->deleteLater();
}

bool StablePropertiesWindowFactory::registerFactory(QObject *factory)
{
    PropertiesWindowTabPagePluginIface *Iface = dynamic_cast<PropertiesWindowTabPagePluginIface*>(factory);
    return PropertiesWindowPluginManager::getInstance()->registerFactory(Iface);
}

bool StablePropertiesWindowFactory::unregisterFactory(QObject *factory)
{
    PropertiesWindowTabPagePluginIface *Iface = dynamic_cast<PropertiesWindowTabPagePluginIface*>(factory);
    return PropertiesWindowPluginManager::getInstance()->unregisterFactory(Iface);
}
